function MenuState() {

    var menu;
    var background;

    this.setup = function() {
        menu = new jaws.Sprite({image: "images/menu.png", x: 100, y: 200});
        background = new jaws.Sprite({color: "#8ED6FF", width: jaws.width, height: jaws.height, x: 0, y: 0});
    };
    this.update = function() {
        if (jaws.pressed("enter")) {
            jaws.switchGameState(PlayState);
        }
    };
    this.draw = function() {
        background.draw();
        menu.draw();
    };
}
function EndState() {

    var end;
    var background;

    this.setup = function() {
        end = new jaws.Sprite({image: "images/end.png", x: 100, y: 200});
        background = new jaws.Sprite({color: "#8ED6FF", width: jaws.width, height: jaws.height, x: 0, y: 0});
    };
    this.update = function() {
        if (jaws.pressed("enter")) {
            jaws.switchGameState(PlayState);
        }
    };
    this.draw = function() {
        background.draw();
        end.draw();
    };
}

function PlayState() {

    var hud;
    var heart;
    var heartSheet;

    var viewport;

    var maxHeight = 1800;

    var player;
    var coins;

    var coral;

    var sea;

    this.setup = function() {

        hud = new jaws.Sprite({color: "black", width: 90, height: 600, x: 510, y: 0});

        heartSheet = new jaws.SpriteSheet({image: "images/heartSheet.png", frame_size: [78, 64], orientation: "right"});

        heart = new jaws.Sprite({image: heartSheet.frames[0], x: 515, y: 30});

        //Viewport of 500x1800
        viewport = new jaws.Viewport({max_x: 500, max_y: maxHeight, width: 500});

        player = new jaws.Sprite({x: 170, y: 30});

        player.dx = 0;
        player.dy = 0;

        player.health = 0;

        player.speed = 4;

        player.move = function() {
            this.x += this.dx;
            this.y += this.dy;

            if (this.y < 32) {
                this.y = 32;
            }
            if (this.y > 1700) {
                this.y = 1700;
            }

            this.dx = this.dy = 0;
        };
        var playerAnim = new jaws.Animation({sprite_sheet: "images/squidAnim.png", frame_size: [56, 56], frame_duration: 380, orientation: "right"});
        player.anim_up = playerAnim.slice(0, 2);
        player.anim_default = playerAnim.slice(3, 5);

        //Coral properties
        coral = new jaws.SpriteList();
        for (var i = 1; i <= 100; i++) {
            coral.push(new jaws.Sprite({x: 0, y: 32 * i}));
            coral.push(new jaws.Sprite({x: 500, y: 32 * i, flipped: true}));
        }

        var coralAnim = new jaws.Animation({sprite_sheet: "images/coralAnim.png", frame_size: [25, 64], frame_duration: 160, orientation: "down"});
        coral.anim_default = coralAnim.slice(0, 2);

        coral.animate = function()
        {
            this.forEach(function(element) {
                element.setImage(coral.anim_default.next());
            });
        };

        coral.check = function() {

            var results = jaws.collideOneWithMany(player, coral);

            if (results.length > 0) {

                player.health++;

                if (player.health > 2) {
                    jaws.switchGameState(EndState);
                }

                heart.setImage(heartSheet.frames[player.health]);

                if (player.x < 250) {
                    player.x += 42;
                } else {
                    player.x -= 42;
                }
            }
        };

        //Coins properties
        coins = new jaws.SpriteList();

        for (var i = 1; i < 10; i++) {
            coins.push(new jaws.Sprite({image: "images/coin.png", x: 80, y: 80 * i}));
        }

        coins.check = function() {

            var results = jaws.collideOneWithMany(player, coins);

            if (results.length > 0) {
                coins.remove(results[0]);
            }
        };

        //Sea properties
        sea = new jaws.Sprite({color: "#8ED6FF", x: 0, y: 30, width: 500, height: maxHeight});

        //Override the default keys
        jaws.preventDefaultKeys(["up", "down", "left", "right"]);

    };
    this.update = function() {

        player.setImage(player.anim_default.next());
        coral.animate();

        if (jaws.pressed("up")) {
            player.dy -= player.speed;
            player.setImage(player.anim_up.next());
        }
        if (jaws.pressed("left")) {
            player.dx -= player.speed;
        }
        if (jaws.pressed("down")) {
            player.dy += player.speed;
            player.setImage(player.anim_up.next());
        }
        if (jaws.pressed("right")) {
            player.dx += player.speed;
        }

        player.dy += 1; //Gravity

        player.move();

        coins.check();

        coral.check();

        viewport.centerAround(player);

    };
    this.draw = function() {
        jaws.clear();
        viewport.apply(function() {
            sea.draw();
            coral.draw();
            player.draw();
            coins.draw();
        });
        hud.draw();
        heart.draw();
    };
}
jaws.onload = function() {
    jaws.assets.add(["images/coin.png", "images/squidAnim.png",
        "images/coralAnim.png", "images/heartSheet.png",
        "images/menu.png", "images/end.png"]);
    jaws.start(MenuState);
};